Neko 1.99.7
A portable framework for high-order spectral element flow simulations
Loading...
Searching...
No Matches
lambda2_kernel.h File Reference
#include "elem_block.h"
Include dependency graph for lambda2_kernel.h:
This graph shows which files directly or indirectly include this file:

Go to the source code of this file.

Functions

template<typename T >
__inline__ __device__ T eigen_val_calc (T grad11, T grad12, T grad13, T grad21, T grad22, T grad23, T grad31, T grad32, T grad33)
 
template<typename T , const int LX, const int CHUNKS>
__global__ void lambda2_kernel_1d (T *__restrict__ lambda2, const T *__restrict__ u, const T *__restrict__ v, const T *__restrict__ w, const T *__restrict__ dx, const T *__restrict__ dy, const T *__restrict__ dz, const T *__restrict__ drdx, const T *__restrict__ dsdx, const T *__restrict__ dtdx, const T *__restrict__ drdy, const T *__restrict__ dsdy, const T *__restrict__ dtdy, const T *__restrict__ drdz, const T *__restrict__ dsdz, const T *__restrict__ dtdz, const T *__restrict__ jacinv)
 
template<typename T , const int LX, const int EB>
__global__ void __launch_bounds__ ((LX *LX *EB), 3) lambda2_kernel_kstep(T *__restrict__ lambda2
 
 if (eb==0)
 
 for (int k=0;k< LX;++k)
 
 __syncthreads ()
 

Variables

__global__ void const T *__restrict__ u
 
__global__ void const T *__restrict__ const T *__restrict__ v
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ w
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dx
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dy
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dz
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ drdx
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dsdx
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dtdx
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ drdy
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dsdy
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dtdy
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ drdz
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dsdz
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dtdz
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ jacinv
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const int nelv
 
__shared__ T shv [EB *LX *LX]
 
__shared__ T shw [EB *LX *LX]
 
__shared__ T shdx [LX *LX]
 
__shared__ T shdy [LX *LX]
 
__shared__ T shdz [LX *LX]
 
const int eb = (EB == 1) ? 0 : threadIdx.z
 
const int e_blk = blockIdx.x * EB + eb
 
const bool active = (EB == 1) ? true : (e_blk < nelv)
 
const int e = active ? e_blk : (nelv - 1)
 
const int sh = eb * LX * LX
 
const int j = threadIdx.y
 
const int i = threadIdx.x
 
const int ij = i + j * LX
 
const int ele = e*LX*LX*LX
 
T ru [LX]
 
T rv [LX]
 
T rw [LX]
 

Function Documentation

◆ __launch_bounds__()

template<typename T , const int LX, const int EB>
__global__ void __launch_bounds__ ( (LX *LX *EB ,
 
)

◆ __syncthreads()

__syncthreads ( )

◆ eigen_val_calc()

template<typename T >
__inline__ __device__ T eigen_val_calc ( T  grad11,
T  grad12,
T  grad13,
T  grad21,
T  grad22,
T  grad23,
T  grad31,
T  grad32,
T  grad33 
)

Device kernel for lambda2 calc

Definition at line 46 of file lambda2_kernel.h.

Here is the call graph for this function:

◆ for()

for ( )

Definition at line 303 of file lambda2_kernel.h.

Here is the call graph for this function:

◆ if()

if ( eb  = = 0)

Definition at line 292 of file lambda2_kernel.h.

◆ lambda2_kernel_1d()

template<typename T , const int LX, const int CHUNKS>
__global__ void lambda2_kernel_1d ( T *__restrict__  lambda2,
const T *__restrict__  u,
const T *__restrict__  v,
const T *__restrict__  w,
const T *__restrict__  dx,
const T *__restrict__  dy,
const T *__restrict__  dz,
const T *__restrict__  drdx,
const T *__restrict__  dsdx,
const T *__restrict__  dtdx,
const T *__restrict__  drdy,
const T *__restrict__  dsdy,
const T *__restrict__  dtdy,
const T *__restrict__  drdz,
const T *__restrict__  dsdz,
const T *__restrict__  dtdz,
const T *__restrict__  jacinv 
)

Definition at line 101 of file lambda2_kernel.h.

Here is the call graph for this function:

Variable Documentation

◆ active

const bool active = (EB == 1) ? true : (e_blk < nelv)

Definition at line 284 of file lambda2_kernel.h.

◆ drdx

◆ drdy

◆ drdz

◆ dsdx

◆ dsdy

◆ dsdz

◆ dtdx

◆ dtdy

◆ dtdz

◆ dx

◆ dy

◆ dz

◆ e

const int e = active ? e_blk : (nelv - 1)

Definition at line 285 of file lambda2_kernel.h.

◆ e_blk

const int e_blk = blockIdx.x * EB + eb

Definition at line 280 of file lambda2_kernel.h.

◆ eb

const int eb = (EB == 1) ? 0 : threadIdx.z

Definition at line 279 of file lambda2_kernel.h.

◆ ele

const int ele = e*LX*LX*LX

Definition at line 290 of file lambda2_kernel.h.

◆ i

Definition at line 288 of file lambda2_kernel.h.

◆ ij

const int ij = i + j * LX

Definition at line 289 of file lambda2_kernel.h.

◆ j

const int j = threadIdx.y

Definition at line 287 of file lambda2_kernel.h.

◆ jacinv

◆ nelv

Initial value:
{
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__shared__ T shu[LX *LX]

Definition at line 260 of file lambda2_kernel.h.

◆ ru

T ru[LX]

Definition at line 298 of file lambda2_kernel.h.

◆ rv

T rv[LX]

Definition at line 299 of file lambda2_kernel.h.

◆ rw

T rw[LX]

Definition at line 300 of file lambda2_kernel.h.

◆ sh

const int sh = eb * LX * LX

Definition at line 286 of file lambda2_kernel.h.

◆ shdx

__shared__ T shdx[LX *LX]

Definition at line 266 of file lambda2_kernel.h.

◆ shdy

__shared__ T shdy[LX *LX]

Definition at line 267 of file lambda2_kernel.h.

◆ shdz

__shared__ T shdz[LX *LX]

Definition at line 268 of file lambda2_kernel.h.

◆ shv

__shared__ T shv[EB *LX *LX]

Definition at line 263 of file lambda2_kernel.h.

◆ shw

__shared__ T shw[EB *LX *LX]

Definition at line 264 of file lambda2_kernel.h.

◆ u

Definition at line 244 of file lambda2_kernel.h.

◆ v

◆ w